pub fn encode(msg: &SyncMessage, writer: &mut impl Write) -> ZamResult<usize>Expand description
Encodes msg onto writer and returns the number of bytes written to the wire.
pub fn encode(msg: &SyncMessage, writer: &mut impl Write) -> ZamResult<usize>Encodes msg onto writer and returns the number of bytes written to the wire.